require(phyloseq)             # 1.4.0 version, for analyses of microbial communities
require(qiime2R)              # 0.99.6 version, for importing qiime artifacts into phyloseq

require(tidyverse)            # 1.3.1 version, for data frame manipulation
require(dplyr)                # 1.0.9 version, for data frame manipulation

require(ggplot2)              # 3.3.6 version, for plotting
require(ggpubr)               # 0.4.0 version, for plotting
require(scales)               # 1.2.0 version, for change scales
require(gridExtra)            # 2.3 version, for multipanel figure elaboration
require(ggplotify)            # 0.1.0 version, to convert pheatmap plot to ggplot object

require(DESeq2)               # 1.36.0 version, for searching biomarkers between groups
require(ComplexHeatmap)       # 2.12.0 version, for Heatmap of posible biomarkers
require(microViz)             # 0.9.1 version, for Spearman Heatmap

require(microbiome)           # 1.18.0 version, for Venn Diagram
require(eulerr)               # 6.1.1 version, for Venn Diagram

require(vegan)                # 2.6-2 for ANOSIM

## Function that moves factor to last level 
## Taken from: https://stackoverflow.com/questions/42773764/set-a-level-of-a-factor-to-be-the-last

lastlevel = function(f, last) {
  if (!is.factor(f)) stop("f must be a factor")
  orig_levels = levels(f)
  if (! last %in% orig_levels) stop("last must be a level of f")
  new_levels = c(setdiff(orig_levels, last), last)
  factor(f, levels = new_levels)
}

## Larger scale with colors mainly distinguishable based on https://stackoverflow.com/questions/9563711/r-color-palettes-for-many-data-classes

c50 <- c(
  "#1C86EE", "#E31A1C", "#008B00", "#6A3D9A", "#FF7F00", #05
  "#000000", "#FFD700", "#7EC0EE", "#FB9A99", "#90EE90", #10
  "#CAB2D6", "#FDBF6F", "#B3B3B3", "#EEE685", "#B03060", #15
  "#FF83FA", "#FF1493", "#0000FF", "#36648B", "#00CED1", #20
  "#00FF00", "#8B8B00", "#CDCD00", "#8B4500", "#996515", #25
  "#104E8B", "#F3A3A4", "#ADFF2F", "#351E4D", "#6E8B3D", #30
  "#3B3C36", "#8B7500", "#4A708B", "#965C5B", "#548B54", #35
  "#99FF99", "#66083A", "#595959", "#F0E68C", "#CD2990", #40
  "#CD69C9", "#B94E48", "#A2A2D0", "#E4D96F", "#528B8B", #45
  "#A7F432", "#9ACD32", "#FEDF00", "#FF7F00", "#8B7500"  #50
)

# Custom ggplot theme

theme_custom = function(){
  theme(
    panel.background = element_blank(),
    legend.key=element_rect(colour=NA, fill =NA),
    strip.background = element_blank(),
    axis.text = element_text(colour = "black"),
    axis.line = element_line(colour = 'black'),
    text = element_text(size = 10, colour = 'black')
  )
}

# The following was written mainly based on this blog entry https://www.yanh.org/2021/01/01/microbiome-r/ 

# get data with qza_to_phyloseq from qiime2R package

ps_samples <- qza_to_phyloseq(features = 'analysis/filtered_table_sample.qza',
                              metadata = 'analysis/metadata_sampleB.tsv',
                              tree = 'analysis/rooted-tree.qza',
                              taxonomy = 'analysis/taxonomy.qza')

set.seed(6669) # set seed for consistency

ps_samples_rarefied <- rarefy_even_depth(ps_samples, rngseed=1,       #normalize sequence at 1000 reads
                                         sample.size=1000, replace=F)

# as result CB25, CB28, CB32 CB47 and L16 were remove because they contained less than 1000 reads

# Next we plot alpha diversity for Observed, Chao1, Shannon and Simspon indexes

alpha_plot <- plot_richness(ps_samples_rarefied, x="cat", color = 'group', 
                            measures=c("Observed", 'Chao1',  "Shannon", "Simpson")) +
geom_boxplot() + labs(color = 'Group') + xlab('') +  theme_custom()

# Function to plot beta diversity by unifrac distance
# takes a phyloseq object ps, and a string group

beta_Plot <- function(ps, group) {
  dist <- phyloseq::distance(ps, method = 'unifrac')  #calculate unifrac distance
  ordination <- ordinate(ps, method = 'PCoA', distance = dist) # make a PCoA ordination
  # Plot the first three axis
  a <- plot_ordination(ps, ordination, shape = group, color = group, axes = c(1,2)) +
    geom_point(size = 2.5) + labs(shape = 'Group', color = 'Group') +
    scale_color_manual(values = c50) +
    theme_custom() +
    theme (plot.title = element_text(hjust = -0.25))
  b <- plot_ordination(ps, ordination, shape = group, color = group, axes = c(2,3)) +
    geom_point(size = 2.5) + labs(shape = 'Group', color = 'Group') +
    scale_color_manual(values = c50) +
    theme_custom()
  c <-  plot_ordination(ps, ordination, shape = group, color = group, axes = c(1,3)) +
    geom_point(size = 2.5) + labs(shape = 'Group', color = 'Group') +
    scale_color_manual(values = c50) +
    theme_custom()
  plot <- ggarrange(a, b, c, ncol = 3, nrow = 1, common.legend = T, legend = 'right')
  return(plot)
}

# subset samples for making the groups for HC, MRS, NRS and EP

ps_HC <- subset_samples(ps_samples_rarefied, group == 'HC')
ps_MRS <- subset_samples(ps_samples_rarefied, group == 'MRS')
ps_NRS <- subset_samples(ps_samples_rarefied, group == 'NRS')
ps_EP <- subset_samples(ps_samples_rarefied, group != 'NRS')

# Function to calculate alpha diversity p values, returns a data frame

alpha.statistic <- function(subset){
  df <- merge(x = rich, data.frame(sample_data(subset)), # add the metadata
        by = 'sample')
  index <- c()  # create two lists in order to make the table
  value <- c()
  indexes <- c('Observed', 'Chao1', 'Simpson', 'Shannon') # define indexes to be calculated
  for (i in indexes) {
    index <- append(index, as.character(i))  # list indexes to be tabulated
    value <- append(value, t.test(get(i) ~ cat, data = df)$p.value) # calculates t test p value, given a subgroup
  }
  values <- tibble(index, value) # makes the table
  return (values)
  
}

#Estimate alpha diversity

rich <- estimate_richness(ps_samples_rarefied, measures = c("Observed", 'Chao1', "Shannon", "Simpson"))
rich$sample <- rownames(rich)

# calculate t test p values for each group

alpha_HC <- alpha.statistic(ps_HC)
alpha_MRS <- alpha.statistic(ps_MRS)
alpha_NRS <- alpha.statistic(ps_NRS)

# gather the groups in a single table

alpha_p <- Reduce(function(...) merge(..., all = TRUE, by = 'index'),
       list(alpha_MRS, alpha_HC, alpha_NRS)) %>%
  dplyr::rename(MRS = 2, HC = 3, NRS = 4 )


# Make beta diversity plots for each group

beta_EP <- beta_Plot(ps_EP, 'cat') # Entero-mammary pathway beta diversity
beta_MRS <- beta_Plot(ps_MRS, 'cat')
beta_HC <- beta_Plot(ps_HC, 'cat')
beta_NRS <- beta_Plot(ps_NRS, 'cat')


# ANOSIM for beta diversity

# define a function that calculates ANOSIM given a phyloseq object

get_ANOSIM_p <- function(subset){
  dist <- phyloseq::distance(subset, method = 'unifrac') # calculates unifrac distance
  result <- anosim(dist, sample_data(subset)$cat)$signif # calculates anosim
  return(result)
}

ANOSIM_p <- c () # make a list to store values
groups <- c () # list to store groups
for (i in c('ps_MRS', 'ps_HC', 'ps_NRS')) {
  groups <- append(groups, i)
  ANOSIM_p <- append(ANOSIM_p, get_ANOSIM_p(ps_MRS)) # get ANOSIM p value for every group
  }
ANOSIM_p <- tibble(groups, ANOSIM_p) # save into a table

# Calculate relative abundance

# Transform counts to relative abundance

ps_relab <- transform_sample_counts(ps_samples_rarefied, function(x) x/sum(x) * 100)

# Function that returns a table filtering taxa < other% abundant

other_taxa <- function(rel_ab, tax_rank, other) {
  glom <- tax_glom(rel_ab, taxrank = tax_rank, NArm = T) # get a table for a given taxonomic rank
  ps_melt <- psmelt(glom) %>%         
    group_by(cat, get(tax_rank)) %>%  # group given a variable called cat and taxonomic rank
    mutate(mean = mean(Abundance))    # calculate taxa Abundance given a category
  ps_melt <- ps_melt %>%              # Taxa < other% are classified as other
    mutate (
      !!  (tax_rank) := ifelse (mean < other, 'Other', get(tax_rank))
    )
  ps_melt_sum  <- ps_melt %>%
    group_by(Sample, cat, group, get(tax_rank)) %>%
    summarise(Abundance = sum (Abundance)) %>%
    mutate(
      !! (tax_rank) := `get(tax_rank)`
    )
  return(ps_melt_sum)
}

other_names <- function(rel_ab, tax_rank, other) {
  glom <- tax_glom(rel_ab, taxrank = tax_rank, NArm = T) # get a table for a given taxonomic rank
  ps_melt <- psmelt(glom) %>%         
    group_by(cat, get(tax_rank)) %>%  # group given a variable called cat and taxonomic rank
    mutate(mean = mean(Abundance))    # calculate taxa Abundance given a category
  ps_melt <- ps_melt %>%              # Taxa < other% are classified as other
    mutate (
      !!  (tax_rank) := ifelse (mean >= other, 'Not other', get(tax_rank))
    ) %>%
    filter(get(tax_rank) != 'Not other') %>%
    filter(Abundance > 0)
  ps_melt_sum  <- ps_melt %>%
    group_by(cat, group, get(tax_rank)) %>%
    summarise(Abundance = mean (Abundance)) %>%
    mutate(
      !! (tax_rank) := `get(tax_rank)`
    ) %>%
    arrange(cat, desc(Abundance))
}



# Get other group for phyla and familiae
rel_abundance_Phyla <- other_taxa(ps_relab, 'Phylum', 1)
other_Phyla <- other_names(ps_relab, 'Phylum', 1)
rel_abundance_Family <- other_taxa(ps_relab, 'Family', 2.5)
other_Family <- other_names(ps_relab, 'Family', 2.5)
write_csv(other_Family, 'other_Family.csv')

# Change factor for graph purposes
rel_abundance_Phyla$group <- relevel(rel_abundance_Phyla$group, 'MRS') # Set MRS to first level
rel_abundance_Phyla$Phylum <- as.factor(rel_abundance_Phyla$Phylum) %>% # convert Phylum to factor
  lastlevel('Other') # Set other to last level
rel_abundance_Family$group <- relevel(rel_abundance_Family$group, 'MRS') # Set MRS to first level
rel_abundance_Family$Family <- as.factor(rel_abundance_Family$Family) %>% # convert Family to factor
  lastlevel('Other') # Set other to last level

# Plot relative abundance for phyla

plot_phylum <- ggplot(rel_abundance_Phyla, aes(x = cat, y = Abundance, fill = Phylum)) + 
  geom_bar(position = 'fill',stat = "identity", aes(fill=Phylum)) +
  scale_y_continuous(label = percent) +
  scale_fill_manual(values = c50) +
  scale_x_discrete(labels = c('( - )', '( + )')) +
  labs(x="", y="Relative Abundance") +
  facet_wrap(~group, scales= "free_x", nrow=1) +
  theme_custom() +
  theme(axis.text.x = element_text(size = 12))

# Plot relative abundance for familiae

plot_family <- ggplot(rel_abundance_Family, aes(x = cat, y = Abundance, fill = Family)) + 
  geom_bar(position = 'fill',stat = "identity", aes(fill = Family)) +
  scale_y_continuous(label = percent) +
  scale_fill_manual(values = c50) +
  scale_x_discrete(labels = c('( - )', '( + )')) +
  labs(x="", y="Relative Abundance") +
  facet_wrap(~group, scales= "free_x", nrow=1) +
  theme_custom() +
  theme(axis.text.x = element_text(size = 12))

# Function that calculate p values for relative abundance of each taxonomic group

relab_statistic_group <- function(rel_ab, tax_rank) {
  tax <- as.character(as.matrix(unique(rel_ab[, tax_rank])))
  group <- as.character(as.matrix(unique(rel_ab[, 'group'])))
  features <- c()
  groups <- c()
  p_val <- c()
  for (i in tax){
    for (x in group) {
      groups <- append(groups, as.character(x))
      features <- append(features, as.character(i))
      p_val <- append(p_val, 
                      t.test(Abundance ~ cat,
                             data = filter(rel_ab, get(tax_rank) == i, group == x )
                             )$p.val)
    }
  }
  result <- tibble(features, groups, p_val)
  return(result)
}

# Calculate p values for relative abundance

relab_statistic_Phyla <- relab_statistic_group(rel_abundance_Phyla, 'Phylum')
rel_abundance_Family <- complete(rel_abundance_Family, Family, Abundance = 0) # in order to make the function work :)
relab_statistic_Family <- relab_statistic_group(rel_abundance_Family, 'Family')



# Heatmap

# extract taxa at genus level
ps_Genus <- tax_glom(ps_samples_rarefied, taxrank = 'Genus', NArm = T)

otu_table(ps_Genus) <- otu_table(ps_Genus) + 1 #sum 1 to matrix

# DESEq analysis
ds <- phyloseq_to_deseq2(ps_Genus, ~ result)
ds <- DESeq(ds, test = 'Wald', fitType = 'parametric')
res <- results(ds, alpha = 0.05)
res <- res[order(res$padj, na.last = NA), ]

# Merge samples for the plot
ps_Genus_group <- merge_samples(ps_Genus, group = 'cat') # Merge samples by cat variable
sample_data(ps_Genus_group) <- qza_to_phyloseq(metadata = 'analysis/metadata_group.tsv') # use new metadata for groups

sig_taxa <- rownames(res[1:20, ]) # select bottom 20 with lowest p.adj values
ps_Genus_rel <- transform_sample_counts(ps_Genus_group, function(x) x/sum(x) * 100)
ps_Genus_rel <- prune_taxa(sig_taxa, ps_Genus_rel) # preserve taxa with lowest p.adj values 

matrix <- data.frame(otu_table(ps_Genus_rel)) %>% # Create matrix from feature table
  t() %>% #transpose matrix
  as.data.frame() %>% # convert to data frame to use select function
  select('MRS+', 'MRS-', 'HC+', 'HC-', 'NRS+', 'NRS-') %>% # reorder groups with select
  as.matrix() # convert to a matrix

# To use ComplexHeatmap function we require sample matrix and sample metadata

rownames(matrix) <- as.character(tax_table(ps_Genus_rel)[, 'Genus']) # Assign Genus name to ASVs in feature table
metada_sub <- data.frame(sample_data(ps_Genus_rel)) # Extract metadata

# Annotation row for phyla annotations

annotation_row <- data.frame(
  Phylum = as.factor(tax_table(ps_Genus_rel)[, 'Phylum'])
)
rownames(annotation_row) <- rownames(matrix)

phylum_col <- RColorBrewer::brewer.pal(length(levels(annotation_row$Phylum)), 'Paired')

names(phylum_col) <- levels(annotation_row$Phylum)

ann_colors <- list(Phylum = phylum_col)

# Plot heatmap

heatmap_EP <- ComplexHeatmap::pheatmap(matrix, scale= "row", 
                                       annotation_row = annotation_row, 
                                       annotation_colors = ann_colors,
                                       cluster_cols = F,
                                       border_color = F,
                                       heatmap_legend_param = list(title = 'Scale'))
# Convert to ggplot object

heatmap_EP <- as.ggplot(heatmap_EP)

# Steps for Venn Diagram

sample_groups <- unique(as.character(meta(ps_Genus_group)$group))

list_core <- c()
for (n in sample_groups){ # for each variable n in grouy
  #print(paste0("Identifying Core Taxa for ", n))
  
  ps_sub <- subset_samples(ps_relab, group == n) # Choose sample from group by n
  
  core_m <- core_members(ps_sub, # ps_sub is phyloseq selected with only samples from g 
                         detection = 0, # 0.001 in atleast 90% samples 
                         prevalence = 0)
  print(paste0("No. of core taxa in ", n, " : ", length(core_m))) # print core taxa identified in each DiseaseState.
  list_core[[n]] <- core_m # add to a list core taxa for each group.
  #print(list_core)
}

mycols <- c(MRS="#8ac1f7", HC="#e56c6d", Both="#7eda7e") 
venn_diagram <- plot(venn(list_core),
                     fills = mycols)


## Spearman correlation with microViz based on this https://david-barnett.github.io/microViz/reference/cor_heatmap.html

# Import phyloseq objects with metadata to be correlated

ps_MRS_spearman <- qza_to_phyloseq(features = 'analysis/filtered_table_sample.qza',
                                   metadata = 'MRS_metadata.tsv',
                                   tree = 'analysis/rooted-tree.qza',
                                   taxonomy = 'analysis/taxonomy.qza')

ps_HC_spearman <- qza_to_phyloseq(features = 'analysis/filtered_table_sample.qza',
                                   metadata = 'HC_metadata.tsv',
                                   tree = 'analysis/rooted-tree.qza',
                                   taxonomy = 'analysis/taxonomy.qza')

ps_NRS_spearman <- qza_to_phyloseq(features = 'analysis/filtered_table_sample.qza',
                                   metadata = 'NRS_metadata.tsv',
                                   tree = 'analysis/rooted-tree.qza',
                                   taxonomy = 'analysis/taxonomy.qza')

# CM15, CM36, L15, L36, CB11, CB26, CB15 and CB36 were removed due to lack of metadata



# Function to calculate spearman correlation matrix
correlation_group <- function(ps){
  ps_spearman <- tax_filter(ps,
                            min_prevalence = 0.1,
                            min_sample_abundance = 0.95) %>%
    tax_fix(unknowns = c('uncultured')) %>%
    tax_agg('Genus')
  # transform counts to log10
  otu <- data.frame(otu_get(ps_spearman) + 1) %>%
    as.matrix() %>%
    log10()
  metadata <- sample_data(ps) %>%
    as.matrix()
  # calculate correaltion by spearman method
  correlation <- associate(otu, metadata,
                           method = 'spearman', mode = 'table',
                           p.adj.threshold = 0.005, n.signif = 1,
                           p.adj.method = 'none')
  return(correlation)
}

# Caculate Spearman correaltion for the groups

correlation_MRS <- correlation_group(ps_MRS_spearman)
correlation_HC <- correlation_group(ps_HC_spearman)
correlation_NRS <- correlation_group(ps_NRS_spearman)

# Plot Spearman correlation

correlation_plot_MRS <- heat(correlation_MRS, "X1", "X2", 
                     fill = "Correlation", 
                     star = "p.adj", 
                     star.size = 5,
                     p.adj.threshold = 0.005) +
  theme_custom() +
  theme(axis.line = element_blank())

correlation_plot_HC <- heat(correlation_HC, "X1", "X2", 
                     fill = "Correlation", 
                     star = "p.adj", 
                     star.size = 5,
                     p.adj.threshold = 0.005) +
  theme_custom() +
  theme(axis.line = element_blank())

correlation_plot_NRS <- heat(correlation_NRS, "X1", "X2", 
                     fill = "Correlation", 
                     star = "p.adj", 
                     star.size = 5,
                     p.adj.threshold = 0.005) +
  theme_custom() +
  theme(axis.line = element_blank())

# Load and plot Sourcetracker data

# Pie chart

ps_mixing <- as.data.frame(otu_table(qza_to_phyloseq('analysis/sourcetracker/mixing_proportions.qza')))
ps_mixing <- ps_mixing %>%
  summarise(MRS = mean(MRS), Unknown = mean(Unknown)) %>%
  t() %>% 
  data.frame() 

proportion <- ps_mixing$.
source <- rownames(ps_mixing)

mixing_prop <- data.frame(source, proportion)

pie_source <- ggplot(mixing_prop, aes(x = "", y = proportion, fill = source)) +
  geom_bar(stat = 'identity', width = 1) +
  coord_polar('y', start = 0) +
  geom_text(aes
            (label = paste(round(proportion, 4)*100, '%')), 
            position = position_stack(vjust = 0.5)) +
  labs(x = NULL, y = NULL, fill = NULL) +
  theme_custom() +
  theme(axis.ticks = element_blank(),
        axis.line = element_blank(),
        axis.text = element_blank(),
        legend.position = 'bottom')

# Relative abundance of "per sink assignments"

ps_assignments <- qza_to_phyloseq(features = 'analysis/sourcetracker/per_sink_assignments.qza',
                                  metadata = 'analysis/sourcetracker/metadata.tsv',
                                  taxonomy = 'analysis/taxonomy.qza')

ps_assignments <- transform_sample_counts(ps_assignments, function(x) x/sum(x)*100)


glom_assign <- tax_glom(ps_assignments, taxrank = 'Genus', NArm = T) # get a table for a given taxonomic rank
ps_melt_assign <- psmelt(glom_assign) %>%         
  group_by(Source, Genus) %>%  # group given a variable called cat and taxonomic rank
  mutate(mean = mean(Abundance))    # calculate taxa Abundance given a category
ps_melt_assign <- ps_melt_assign %>%              # Taxa < other% are classified as other
  mutate (
    Genus = ifelse (mean < 0.5, 'Other', Genus)
  )
ps_assign_sum  <- ps_melt_assign %>%
  group_by(Sample, Source, Genus) %>%
  summarise(Abundance = sum (Abundance))

# Remove long names

ps_assign_sum$Genus <- gsub("([a-z|A-Z]*)(_|-)(\\w*)", 
                            "\\1", ps_assign_sum$Genus, perl=T) %>%
  as.factor() %>%
  lastlevel('Other') # set other as last level factor

# Plot relative abundance of sourcetracker

bp_source <- ggplot(ps_assign_sum, aes(x = Source, y = Abundance, fill = Genus)) +
  geom_bar(position = 'fill', stat = 'identity', aes(fill=Genus)) +
  labs(x='', y = '') +
  scale_y_continuous(label = percent) +
  scale_fill_manual(values = c50) +
  theme_custom()

# Load results from LEFSE

LEFSE_results <- read_tsv('LEFSE_values.tsv')


# Adjust p value with Benjamin-Hochberg correction (False discovery rate)

LEFSE_results <- LEFSE_results %>%
  group_by(group) %>%
  mutate(
    q.value = p.adjust(p.value, 'BH')
           )

write_csv(LEFSE_results, 'LEFSE_values_adjust.csv')

# Generate and export figures

# Figure 1. Relative abundance for familia and phylum


figure1 <- grid.arrange(arrangeGrob(plot_phylum, top = text_grob('A', face = 'bold', x = 0, hjust = 0, size = 15)),
                        arrangeGrob(plot_family, top = text_grob('B', face = 'bold', x = 0, hjust = 0, size = 15)))

ggsave('figures/Numbered_figures/figure1.jpg', figure1, dpi = 600, height = 8, width = 10)

# Figure 2. Alpha and beta diversity


figure2 <- grid.arrange(arrangeGrob(alpha_plot, top = text_grob('A', face = 'bold', x = 0, hjust = 0, size = 15)),
             arrangeGrob(beta_EP, top = text_grob('B', face = 'bold', x = 0, hjust = 0, size = 15)))

ggsave('figures/Numbered_figures/figure2.jpg', figure2, dpi = 600, height = 6, width = 10)

# Figure 4. Venn diagram and heatmap

figure4 <- grid.arrange(arrangeGrob(venn_diagram, top = text_grob('A', face = 'bold', x = 0, hjust = 0, size = 15)),
                        arrangeGrob(heatmap_EP, top = text_grob('B', face = 'bold', x = 0, hjust = 0, size = 15)), ncol = 2, nrow = 1, widths = c (1,2))

ggsave('figures/Numbered_figures/figure4.jpg', figure4, dpi = 600, height = 5, width = 10)


# Figure 5. Sourcetracker results

figure5 <- grid.arrange(arrangeGrob(pie_source, top = text_grob('A', face = 'bold', x = 0, hjust = 0, size = 15)),
                        arrangeGrob(bp_source, top = text_grob('B', face = 'bold', x = 0, hjust = 0, size = 15)), ncol = 2, nrow = 1)

ggsave('figures/Numbered_figures/figure5.jpg', figure5, dpi = 600, height = 6, width = 10)

# Figure 6. Spearman correlation analysis

figure6 <- grid.arrange(arrangeGrob(correlation_plot_MRS, top = text_grob('A', face = 'bold', x = 0, hjust = 0, size = 15)),
                        arrangeGrob(correlation_plot_HC, top = text_grob('B', face = 'bold', x = 0, hjust = 0, size = 15)),
                        arrangeGrob(correlation_plot_NRS, top = text_grob('C', face = 'bold', x = 0, hjust = 0, size = 15)), ncol = 1, nrow =3)

ggsave('figures/Numbered_figures/figure6-1.jpg', figure6, dpi = 600, height = 10, width = 8)

# Figure S1. Beta diversity for MRS, HC and NRS

figureS1 <- grid.arrange(arrangeGrob(beta_MRS, top = text_grob('A', face = 'bold', x = 0, hjust = 0, size = 15)),
                        arrangeGrob(beta_HC, top = text_grob('B', face = 'bold', x = 0, hjust = 0, size = 15)),
                        arrangeGrob(beta_NRS, top = text_grob('C', face = 'bold', x = 0, hjust = 0, size = 15)))

ggsave('figures/Numbered_figures/figureS1.jpg', figureS1, dpi = 600, height = 8, width = 8)
